package PAR::StrippedPARL::Dynamic;
use strict;
use warnings;
use vars qw/$VERSION/;
$VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M?T5,1@$!`0````````````(``P`!````$)H$"#0```#LL0```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(C*P`
M`(RL```%`````!````$```",K```C#P%"(P\!0B``@``+!,```8`````$```
M`@```*"L``"@/`4(H#P%"``!`````0``!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%#E=&0DJP``)"L%""0K!0A,````3`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````)````
M)0```$H````0````"0```&`<H+````8`@`!0`0((``D`P0"`"0!#<0"`%```
M!`!```````=``((L4@``E92`I`0(`$!A8$9)>``$%8HF#8A*````2P```$X`
M``!0````40```%,```!6````6`````````!9````6@````````!;````70``
M`%\`````````8```````````````80```&(```````````````````!E````
M:````&D```!L````;P```'````!S`````````'4```!V````=P```'H`````
M````6>CM[.;_,*+.WD<MH^#[2;ZBA50'%D8@'_C1#4@+K86W??Y,ZM/O#J;=
MHVNQ.G4&+L6;MA>J5W?;S>.>B9YL_&L)0]8,.I<+GYS)HDQ=1-3%B060#13B
MGB'_Y`X+BA!7L@&+;\2YG$!K?YI\;L7?']AQ6!Q[F77YN^.2?-1DU'RL2^/`
MZWPDJ3)BV^W@IP(*@Q>:Y(O]1\5FK\QF8!;)67OP2FOB1\8!0T75[$?L,SI]
M08[%PN4_++AXVQ2W@(5D(//9,/+;TQWZH6Q@N8WQ#@``````````````````
M```"`P```````"P````2````YP````````!-`0``$@```$8#````````,```
M`!(````Q`P```````#X````2````#0$````````@````$@```(<`````````
M/P```!(```!3`@```````$D$```2````:`,```````#?````$@```",#````
M````V@```!(````,```````````````@````&P``````````````(````/X!
M````````!````!$````W`P```````,,#```2````]P,```````!%````$@``
M`(X#````````U````!(````;`P```````)@````2````KP(```````!$````
M$@```+H!````````Y`,``!(```"3`````````%8#```2````J@$```````#V
M$0``$@```#@!````````E@```!(```!T`P```````#H````2````=0$`````
M```L`0``$@```-L#````````G@$``!(```#0`````````#`````2````.P``
M```````$````$0```&\#````````=@```!(```!Q`@```````#H````2````
M9`$```````#?`0``$@```!(!````````@P$``!(```#5`0```````+4!```2
M`````00```````!%````$@```,T#````````/@```!(```"I`@```````(8`
M```2````A@,```````"$````$@```)4#````````0P```!(````O````````
M`$<&```2````4P$````````$````$0```&@`````````'`<``!(```"[`P``
M`````,L````2````K`,```````!K`P``$@```"X!````````#````!$````J
M`P```````#H````2````P0`````````K`0``$@```*("````````7@```!(`
M``##`0```````)4````2````%@(```````!T`@``$@```!(#````````2```
M`!(```"Q`@```````&L````2````"`(````````K#P``$@```%L#````````
M?`$``!(```!J`@```````'<!```2````(@$```````"/````$@```&(#````
M````.@```!(```"W`@```````%0"```2````5`,````````2`0``$@```*,#
M````````0````!(```#%`P```````"4!```2````7@(```````"Q````$@``
M`/4`````````D````!(````_`P```````)L!```2````"@,```````#E````
M$@```$@"````````*P```!(```#C`0```````%4$```2````30,```````!$
M````$@```+,#````````HP```!(```#4`P```````$0````2````_0(`````
M``#[````$@```(,!````````<@```!(```"1`0````````0````1````2`$`
M```````H````$@```%$`````````?0```!(```"O`````````!,+```2````
M=P0``&#8!`@$````$0`.`,P%```@VP0(KTT``!$`#@#U!0``K+T$"(0&```2
M``P`(08``+VC!`BU`0``$@`,``(!```H/P4(!````!$`&`"A````+#\%"`$`
M```1`!@`;P$``#0_!0@$````$0`8`)\!```\/P4(`0```!$`&``T!0``<-,$
M""<!```2``P`<00``#C8!`@`````$@`-`.\#``!$/P4(!````"$`&`!W````
M2#\%"`0````1`!@`200``.&?!`@-````$@`,`#$"```D/P4(!````!$`&`!P
M!0``4-<$"%<````2``P`1P```#`_!0@$````$0`8`!<%``#L/@4(`````!``
M%P`9!0``[#X%"``````@`!<`T`0``.#5!`A<`0``$@`,`.X!``!`/P4(!```
M`!$`&`#N`P``1#\%"`0````A`!@`9P0``$#7!`@%````$@`,`!0&``#NGP0(
M2`(``!(`#`#:````3#\%"`$````1`!@`E`0``'*E!`A8````$@`,`.T#``!$
M/P4(!````!$`&`#H`P``M<H$"#$"```2``P`Q`0``*W%!`A[````$@`,`!,$
M```,/P4(`````!``\?_6!0``\,P$"&8````2``P`'P0``+A/!0@`````$`#Q
M_WX$``#2Q@0(J@,``!(`#`#N`@``9-@$"`0````1``X`404``*#0!`CG````
M$@`,`!T%```0F@0(`````!(`#`"B!```!I\$"-L````2``P`^@0``*#4!`@]
M`0``$@`,`"0"```X/P4(!````!$`&`"X!```>*($"$4!```2``P`ZP0```@_
M!0@$````$0`7`"0%``!@S00(/0,``!(`#`!:!```-J($"$(````2``P`#`0`
M``P_!0@`````$`#Q_\<%```$/P4(!````!$`%P">!0``JL8$""@````2``P`
M:`4``+2:!`@J````$@`,`(`%``"0T00(3`$``!(`#`"Z!0``,,0$"'T!```2
M``P`%P$``"`_!0@$````$0`8`'P"``!0/P4($P```!$`&``"!@``0+P$"&P!
M```2``P`:@4``+B5!`@`````$@`*``!L:6)P97)L+G-O`%]?9VUO;E]S=&%R
M=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S=E\R:78`4$Q?<W1A8VM?
M<W``4$Q?8V]M<&-V`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`<&5R;%]C;VYS
M=')U8W0`4$Q?<VEG9G!E7W-A=F5D`%!E<FQ?9V5T7W-V`%!E<FQ?879?<VAI
M9G0`4$Q?97AI=%]F;&%G<P!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E
M='!V;@!097)L7V9O<FT`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T:78`4&5R
M;%]N97=35G!V`%!,7VEN7V5V86P`<&5R;%]F<F5E`%!,7VQI;F5S='(`4&5R
M;%]M9U]S970`4$Q?<W9?>65S`%!E<FQ?<W9?,FUO<G1A;`!097)L7VYE=U)6
M`%!,7VUA<FMS=&%C:U]P='(`4&5R;%]V;65S<P!03%]O<`!097)L7W-V7W-E
M='!V`%!E<FQ?;F5W4U9P=FX`4$Q?<W1A8VM?8F%S90!03%]T86EN=&5D`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7W-V7VYE=VUO<G1A;`!097)L
M7V1O=6YW:6YD`%!E<FQ?;F5W6%,`4$Q?8W5R<W1A8VMI;F9O`%!,7V-U<G!A
M9`!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`4$Q?979A;%]R;V]T`%!,
M7W!E<FQ?9&5S=')U8W1?;&5V96P`4&5R;%]C<F]A:P!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8FYS;"YS;RXQ`&QI8F1L+G-O+C(`9&QO<&5N`&1L<WEM`&1L8VQO<V4`9&QE
M<G)O<@!L:6)M+G-O+C8`;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB
M8RYS;RXV`%])3U]S=&1I;E]U<V5D`&5X:70`<W!R:6YT9@!S=')N8VUP`&-L
M;W-E9&ER`'-T<FYC<'D`<VEG;F%L`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE
M;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')S='(`<FUD:7(`;W!E;C8T
M`')E860`7U]S=')T;VQ?:6YT97)N86P`;W!E;F1I<@!G971E;G8`7U]C='EP
M95]B7VQO8P!R96%D;&EN:P!E>&5C=G``;'-E96LV-`!R96%D9&ER-C0`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7WAS=&%T-C0`7U]L>'-T870V-`!?961A=&$`7U]B<W-?<W1A<G0`7V5N
M9``O=7-R+VQI8B]P97)L-2\U+C@N."]I,S@V+6QI;G5X+T-/4D4`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%]F<%]H
M=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<&%R7V-L96%N=7``6%-?1'EN
M84QO861E<E]D;%]L;V%D7V9I;&4`<VEZ95]L;V%D7VUE7S(`6%-?1'EN84QO
M861E<E]D;%]U;FQO861?9FEL90!?7V1A=&%?<W1A<G0`8F]O=%]$>6YA3&]A
M9&5R`%A37T1Y;F%,;V%D97)?9&Q?9FEN9%]S>6UB;VP`6%-?1'EN84QO861E
M<E]D;%]E<G)O<@!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]$>6YA3&]A
M9&5R7V1L7VEN<W1A;&Q?>'-U8@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!
M0TL`<&%R7W)M=&UP9&ER`&YA;65?;&]A9%]M95\R`%A37T1Y;F%,;V%D97)?
M9&Q?=6YD969?<WEM8F]L<P!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$`1TQ)0D-?
M,BXP`$=,24)#7S(N,P!'3$E"0U\R+C(````"`````@`"``````````,``@``
M```````"``0``@`"``4````````````"`````@```````@```````@````0`
M`@`%``(`!@`````````$``(````"````!P```````@`"`````@`"`````@`%
M``(``@`"```````"``(```````(``P`"``(```````````````$``0`!``$`
M```````````!``$``@````$````!`````0`!``$````"``$``0````$``@`!
M``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$``0`!``$``0`!````
M```!``$````!``(`EP(``!`````P````$6EI#0``!P`N!@``$````!!I:0T`
M``4`.`8````````!``0`Y`(``!``````````$VEI#0``!@!"!@``$````!)I
M:0T```0`3`8``!`````1:6D-```#`"X&```0````$&EI#0```@`X!@``````
M`*`]!0@&"@``I#T%"`8,``"H/04(!EP``*P]!0@&&@``L#T%"`9N``"T/04(
M!E```#0_!0@%4```N#T%"`8F``"\/04(!BH``,`]!0@&4@``Q#T%"`9K``#(
M/04(!G@``,P]!0@&9P``T#T%"`9&```@/P4(!7H``"0_!0@%5P``*#\%"`5.
M```L/P4(!4\``#`_!0@%60``.#\%"`5O```\/P4(!5$``$`_!0@%70``1#\%
M"`5C``!(/P4(!54``$P_!0@%80``4#\%"`5[``#@/04(!P$``.0]!0@'`@``
MZ#T%"`<#``#L/04(!P0``/`]!0@'!0``]#T%"`<&``#X/04(!P<``/P]!0@'
M"````#X%"`<)```$/@4(!PH```@^!0@'#0``##X%"`<.```0/@4(!P\``!0^
M!0@'$```&#X%"`<1```</@4(!Q(``"`^!0@'$P``)#X%"`<4```H/@4(!Q4`
M`"P^!0@'%@``,#X%"`<7```T/@4(!Q@``#@^!0@'&0``/#X%"`<;``!`/@4(
M!QP``$0^!0@''0``2#X%"`<>``!,/@4(!Q\``%`^!0@'(```5#X%"`<A``!8
M/@4(!R(``%P^!0@'(P``8#X%"`<D``!D/@4(!R4``&@^!0@')P``;#X%"`<H
M``!P/@4(!RD``'0^!0@'*P``>#X%"`<L``!\/@4(!RT``(`^!0@'+@``A#X%
M"`<O``"(/@4(!S```(P^!0@',0``D#X%"`<R``"4/@4(!S,``)@^!0@'-```
MG#X%"`<U``"@/@4(!S8``*0^!0@'-P``J#X%"`<X``"L/@4(!SD``+`^!0@'
M.@``M#X%"`<[``"X/@4(!SP``+P^!0@'/0``P#X%"`<^``#$/@4(!S\``,@^
M!0@'0```S#X%"`=!``#0/@4(!T(``-0^!0@'0P``V#X%"`=$``#</@4(!T4`
M`.`^!0@'1P``Y#X%"`=(``#H/@4(!TD``%6)Y8/L".AQ!```Z,@$``#H0T(`
M`,G#`/\UV#T%"/\EW#T%"`````#_)>`]!0AH`````.G@_____R7D/04(:`@`
M``#IT/____\EZ#T%"&@0````Z<#_____)>P]!0AH&````.FP_____R7P/04(
M:"````#IH/____\E]#T%"&@H````Z9#_____)?@]!0AH,````.F`_____R7\
M/04(:#@```#I</____\E`#X%"&A`````Z6#_____)00^!0AH2````.E0____
M_R4(/@4(:%````#I0/____\E##X%"&A8````Z3#_____)1`^!0AH8````.D@
M_____R44/@4(:&@```#I$/____\E&#X%"&AP````Z0#_____)1P^!0AH>```
M`.GP_O___R4@/@4(:(````#IX/[___\E)#X%"&B(````Z=#^____)2@^!0AH
MD````.G`_O___R4L/@4(:)@```#IL/[___\E,#X%"&B@````Z:#^____)30^
M!0AHJ````.F0_O___R4X/@4(:+````#I@/[___\E/#X%"&BX````Z7#^____
M)4`^!0AHP````.E@_O___R5$/@4(:,@```#I4/[___\E2#X%"&C0````Z4#^
M____)4P^!0AHV````.DP_O___R50/@4(:.````#I(/[___\E5#X%"&CH````
MZ1#^____)5@^!0AH\````.D`_O___R5</@4(:/@```#I\/W___\E8#X%"&@`
M`0``Z>#]____)60^!0AH"`$``.G0_?___R5H/@4(:!`!``#IP/W___\E;#X%
M"&@8`0``Z;#]____)7`^!0AH(`$``.F@_?___R5T/@4(:"@!``#ID/W___\E
M>#X%"&@P`0``Z8#]____)7P^!0AH.`$``.EP_?___R6`/@4(:$`!``#I8/W_
M__\EA#X%"&A(`0``Z5#]____)8@^!0AH4`$``.E`_?___R6,/@4(:%@!``#I
M,/W___\ED#X%"&A@`0``Z2#]____)90^!0AH:`$``.D0_?___R68/@4(:'`!
M``#I`/W___\EG#X%"&AX`0``Z?#\____):`^!0AH@`$``.G@_/___R6D/@4(
M:(@!``#IT/S___\EJ#X%"&B0`0``Z<#\____):P^!0AHF`$``.FP_/___R6P
M/@4(:*`!``#IH/S___\EM#X%"&BH`0``Z9#\____);@^!0AHL`$``.F`_/__
M_R6\/@4(:+@!``#I</S___\EP#X%"&C``0``Z6#\____)<0^!0AHR`$``.E0
M_/___R7(/@4(:-`!``#I0/S___\ES#X%"&C8`0``Z3#\____)=`^!0AHX`$`
M`.D@_/___R74/@4(:.@!``#I$/S___\EV#X%"&CP`0``Z0#\____)=P^!0AH
M^`$``.GP^____R7@/@4(:``"``#IX/O___\EY#X%"&@(`@``Z=#[____)>@^
M!0AH$`(``.G`^___,>U>B>&#Y/!05%)H0-<$"&A0UP0(459HM<H$".C__/__
M])"058GE4X/L!.@`````6X'#E*,``(N3S/___X72=`7H&OS__UA;R<.0D)"0
MD)!5B>6#[`B`/60_!0@`=`SK'(/`!*/T/@4(_]*A]#X%"(L0A=)UZ\8%9#\%
M"`')PY!5B>6#[`BAG#P%"(7`=!*X`````(7`=`G'!"2</`4(_]#)PY!5B>6#
M["C'1?QHV`0(BT7\B40D",=$)`1@S00(QP0D<M@$".BD_O__R<-5B>6!["@0
M``#'1"0(_P\``(V%_.___XE$)`3'!"2.V`0(Z`O^__^)1?R#??P`?A:+1?R#
MZ`$/MH0%_.___X3`=02#;?P!@WW\`'X_BT7\B40D",=$)`0O````C87\[___
MB00DZ`G^__^%P'0>BT7\B40D"(V%_.___XE$)`2+10B)!"3HV?S__^L2BT4,
MB40D!(M%"(D$).BE^___R<-5B>6#["B#?0@`=`FA1#\%"(7`=0S'1>P`````
MZ:````"+10B)1?3K!(-%]`&+5?0/M@*$P'0*BTWT#[8!/#UUZ(M5](M%"(G1
M*<&)3?"A1#\%"(E%^.M4BT7PB40D"(M5"(E4)`2+3?R)#"3H<OW__X7`=3.+
M1?`#1?P/M@`\/74FBU7XH40_!0B)T2G!B<C!^`*)PHM%#(D0BT7P`T7\@\`!
MB47LZQF#1?@$BT7XBP")1?R#??P`=9['1>P`````BT7LR<-5B>6#[!B-1?R)
M1"0$BT4(B00DZ"+____)PU6)Y5=3@^Q`BU4,#[8"/#UU!(-%#`&+10RY____
M_XE%U+@`````_(M]U/*NB<CWT(/H`8E%](U%\(E$)`2+10B)!"3HV/[__XE%
MW(-]W`!T5(M%W+G_____B470N`````#\BWW0\JZ)R/?0@^@!.T7T#X(&`0``
MBU4,#[8"BTW<B`&+?=P/M@>$P`^5P(-%W`&#10P!A,!UWL=%V`````#IK`$`
M`*%$/P4(B47DQT7@`````.L(@T7D!(-%X`&+5>2+`H7`=>^A@#\%"(7`=#:+
M1>#!X`*#P`B)PJ%$/P4(B50D!(D$).@W^?__HT0_!0BA1#\%"(7`=63'1=C_
M____Z4L!``#'!8`_!0@!````BT7@P>`"@\`(B00DZ$+[__^)1>2#?>0`=0S'
M1=C_____Z1L!``"+1>#!X`*+%40_!0B)1"0(B50D!(M-Y(D,).AN^___BWWD
MB3U$/P4(BT7@P>`"B<*A1#\%"(T$`H/`!,<``````(M%X(E%\(M%"(E%W.L$
M@T7<`8M5W`^V`H3`=`J+3=P/M@$\/77HBT7PP>`"B<*A1#\%"(T<`HM5W(M%
M"(G7*<>)^`-%](/``HD$).B<^O__B0.+`X7`=0G'1=C_____ZWF+1?#!X`*)
MPJ%$/P4(C00"BP")1=SK!(-%W`&+10@/M@"+5=R(`HM-W`^V`83`#Y7`@T4(
M`8/P`83`=0J+?=P/M@<\/771BT7<Q@`]@T7<`8M5#`^V`HM-W(@!BWW<#[8'
MA,`/E<"#1=P!@T4,`83`==['1=@`````BT78@\1`6U]=PU6)Y8/L*.LNBT7\
MP>`"B<*A1#\%"`'"B57LBT7L@\`$BP"+5>R)`HM5[(L"A<!T!H-%[`3KY(U%
M_(E$)`2+10B)!"3H??S__X7`=;S)PU6)Y5=6@>PP(```QT7P`````.CC]O__
MQT0D#*'8!`B)1"0(QT0D!*78!`B-A>_O__^)!"3HH?;__XE%](-]]`!Y#,>%
MY-___P````#K?<=$)`@`$```C87NW___B40D!(V%[^___XD$).B<^?__B47T
M@WWT`'D,QX7DW___`````.M(BT7T@\`!B00DZ"GY__^)1?"#??``=0S'A>3?
M__\`````ZR6+3?2+1?"-E>[?__^)QXG6_/.DBT7T`T7PQ@``BT7PB87DW___
MBX7DW___@<0P(```7E]=PU6)Y8/L".@:____R<-5B>57@>R4$```QP0DL=@$
M".@__/__B47XH?@^!0B)1"0$BT4(B00DZ)7X__^%P'0ABT4(B40D!,<$)+K8
M!`CH*_S__XM%"(F%B.___^GG`0``BT4(N?____^)A83O__^X`````/R+O83O
M___RKHG(]]"#Z`&)1?"A_#X%"(E$)`2+10R)!"3HAOC__XE%[.E_`0``BT7L
M#[8`A,!U!\=%[,?8!`B#??@`=#.+1>R)1"0$BT7XB00DZ`7Y__^%P'4=H?P^
M!0B)1"0$QP0D`````.@\^/__B47LZ34!``"+1>RY_____XF%@.___[@`````
M_(N]@.____*NB<CWT(/H`8E%].L-@VWT`8M%]`-%[,8``(M%]`-%[(/H`0^V
M$*'X/@4(#[8`.,)TVXM%\`-%]#W^#P``?B&+10B)1"0$QP0DNM@$".@D^___
MBT4(B86([___Z>````"+%?@^!0B+10B)1"00B50D#(M%[(E$)`C'1"0$R=@$
M"(V%[.___XD$).AK]/__C86,[___B40D!(V%[.___XD$).@C-@``A<!U6(N%
MG.___R4`\```/0"```!U1L=$)`0!````C87L[___B00DZ/?U__^%P'4LC87L
M[___B40D!,<$)+K8!`CHBOK__XV%[.___XD$).BO]___B86([___ZSZA_#X%
M"(E$)`3'!"0`````Z`+W__^)1>R#?>P`#X5W_O__BT4(B40D!,<$)+K8!`CH
M/_K__XM]"(F]B.___XN%B.___X'$E!```%]=PU6)Y8/L$(M%"(E%^(M%"(E%
M_.L?BT7\#[80H?@^!0@/M@`XPG4)BT7\@\`!B47X@T7\`8M%_`^V`(3`==>+
M1?C)PU6)Y5>#["2#?0@`=`J+10@/M@"$P'44QP0DQ]@$".CU]O__B47TZ1$!
M``"+10BY_____XE%\+@`````_(M]\/*NB<CWT(/H`0-%"(/H`8E%^.L$@VWX
M`8M%^#M%"'89BU7X#[8"BQ7X/@4(#[82.-!TX>L$@VWX`8M-^#M-"'83BWWX
M#[8'BQ7X/@4(#[82.-!UX8M%^#M%"'4VBU7X#[8"BQ7X/@4(#[82.-!U$<<$
M),?8!`CH7O;__XE%].M]H?@^!0B)!"3H3/;__XE%].MK@VWX`8M-^#M-"'83
MBWWX#[8'BQ7X/@4(#[82.-!TX8M5^(M%"(G1*<&)R(/``CT`$```=@G'1?0`
M````ZRV+5?B+10B)URG'B?B#P`&)1"0(BT4(B40D!,<$)*`_!0CH`_/__\=%
M]*`_!0B+1?2#Q"1?7<-5B>6#[$BA?-D$"(E%VJ&`V00(B47>H839!`B)1>*A
MB-D$"(E%YJ&,V00(B47JH9#9!`B)1>ZAE-D$"(E%\J&8V00(B47V#[<%G-D$
M"&:)1?K'!"30V`0(Z)[Z___'!"3@V`0(Z)+Z___'!"2QV`0(Z(;Z___'!"3L
MV`0(Z'KZ___'!"3VV`0(Z&[Z___'!"0`V00(Z&+Z___'!"2ZV`0(Z%;Z___'
M!"0*V00(Z$KZ___'!"03V00(Z#[Z___'!"0>V00(Z+WW__^)1?R#??P`=!.+
M1?R)1"0$QP0D]M@$".B[]___QP0D+]D$".B5]___B47\@WW\`'03BT7\B40D
M!,<$)$'9!`CHD_?__\<$)$S9!`CH;??__XE%_(-]_`!T%8M%_(E$)`3'!"2Q
MV`0(Z&OW___K:,<$)%S9!`CH0_?__XE%_(-]_`!T%8M%_(E$)`3'!"3LV`0(
MZ$'W___K/HU%VH/`$8E%_,=$)`@*````QT0D!&W9!`B+1?R)!"3H'O3__X7`
M=1:+1?R#P`J)1"0$QP0D[-@$".@!]___QT0D!'C9!`C'!"30V`0(Z.WV___)
MPU6)Y8/L&*$`/P4(@_C_=4''!"3LV`0(Z+7V__^)1?R#??P`=!V+1?P/M@"$
MP'03BT7\#[8`/#!T"<=%[`$```#K!\=%[`````"+1>RC`#\%"*$`/P4(R<-5
MB>6!['`!``"+10B#P!R)1>#'1=P`````ZT^+1>"+`(E%Y(-%X`2+3=R+1>3!
MX!B)PH'B````_XM%Y,'@""4``/\`"<*+1>3!Z`@E`/\```G"BT7DP>@8)?\`
M```)T(F$C9S^__^#1=P!@WW<#WZKQT7<$````.M?BTW<BT7<@^@#BY2%G/[_
M_XM%W(/H"(N$A9S^__\QPHM%W(/H#HN$A9S^__\QPHM%W(/H$(N$A9S^__\Q
MT(F$C9S^__^+5=R+1=R+A(6<_O__P<@?B825G/[__X-%W`&#?=Q/?IN+10B+
M`(E%Z(M%"(M`!(E%[(M%"(M`"(E%\(M%"(M`#(E%](M%"(M`$(E%^(V%G/[_
M_XE%_(M%Z(G!P<D;BT7PBU7L(<*+1>SWT"-%]`G0C00!B<(#5?B+1?R+`(T$
M`@69>8):B47D@T7\!,%-[`*+1>2)P<')&XM%[(M5Z"'"BT7H]]`C1?`)T(T$
M`8G"`U7TBT7\BP"-!`(%F7F"6HE%^(-%_`3!3>@"BT7XB<'!R1N+1>B+5>0A
MPHM%Y/?0(T7L"="-!`&)P@-5\(M%_(L`C00"!9EY@EJ)1?2#1?P$P4WD`HM%
M](G!P<D;BT7DBU7X(<*+1?CWT"-%Z`G0C00!B<(#5>R+1?R+`(T$`@69>8):
MB47P@T7\!,%-^`*+1?")P<')&XM%^(M5]"'"BT7T]]`C1>0)T(T$`8G"`U7H
MBT7\BP"-!`(%F7F"6HE%[(-%_`3!3?0"BT7LB<'!R1N+1?2+5?`APHM%\/?0
M(T7X"="-!`&)P@-5Y(M%_(L`C00"!9EY@EJ)1>B#1?P$P4WP`HM%Z(G!P<D;
MBT7PBU7L(<*+1>SWT"-%]`G0C00!B<(#5?B+1?R+`(T$`@69>8):B47D@T7\
M!,%-[`*+1>2)P<')&XM%[(M5Z"'"BT7H]]`C1?`)T(T$`8G"`U7TBT7\BP"-
M!`(%F7F"6HE%^(-%_`3!3>@"BT7XB<'!R1N+1>B+5>0APHM%Y/?0(T7L"="-
M!`&)P@-5\(M%_(L`C00"!9EY@EJ)1?2#1?P$P4WD`HM%](G!P<D;BT7DBU7X
M(<*+1?CWT"-%Z`G0C00!B<(#5>R+1?R+`(T$`@69>8):B47P@T7\!,%-^`*+
M1?")P<')&XM%^(M5]"'"BT7T]]`C1>0)T(T$`8G"`U7HBT7\BP"-!`(%F7F"
M6HE%[(-%_`3!3?0"BT7LB<'!R1N+1?2+5?`APHM%\/?0(T7X"="-!`&)P@-5
MY(M%_(L`C00"!9EY@EJ)1>B#1?P$P4WP`HM%Z(G!P<D;BT7PBU7L(<*+1>SW
MT"-%]`G0C00!B<(#5?B+1?R+`(T$`@69>8):B47D@T7\!,%-[`*+1>2)P<')
M&XM%[(M5Z"'"BT7H]]`C1?`)T(T$`8G"`U7TBT7\BP"-!`(%F7F"6HE%^(-%
M_`3!3>@"BT7XB<'!R1N+1>B+5>0APHM%Y/?0(T7L"="-!`&)P@-5\(M%_(L`
MC00"!9EY@EJ)1?2#1?P$P4WD`HM%](G!P<D;BT7DBU7X(<*+1?CWT"-%Z`G0
MC00!B<(#5>R+1?R+`(T$`@69>8):B47P@T7\!,%-^`*+1?")P<')&XM%^(M5
M]"'"BT7T]]`C1>0)T(T$`8G"`U7HBT7\BP"-!`(%F7F"6HE%[(-%_`3!3?0"
MBT7LB<'!R1N+1?2+5?`APHM%\/?0(T7X"="-!`&)P@-5Y(M%_(L`C00"!9EY
M@EJ)1>B#1?P$P4WP`HM%Z(G!P<D;BT7PBU7L(<*+1>SWT"-%]`G0C00!B<(#
M5?B+1?R+`(T$`@69>8):B47D@T7\!,%-[`*+1>2)P<')&XM%[(M5Z"'"BT7H
M]]`C1?`)T(T$`8G"`U7TBT7\BP"-!`(%F7F"6HE%^(-%_`3!3>@"BT7XB<+!
MRAN+1>@S1>0S1>R-!`*)P@-5\(M%_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%
M](G"P<H;BT7D,T7X,T7HC00"B<(#5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-
M^`*+1?")PL'*&XM%^#-%]#-%Y(T$`HG"`U7HBT7\BP"-!`(%H>O9;HE%[(-%
M_`3!3?0"BT7LB<+!RAN+1?0S1?`S1?B-!`*)P@-5Y(M%_(L`C00"!:'KV6Z)
M1>B#1?P$P4WP`HM%Z(G"P<H;BT7P,T7L,T7TC00"B<(#5?B+1?R+`(T$`@6A
MZ]ENB47D@T7\!,%-[`*+1>2)PL'*&XM%[#-%Z#-%\(T$`HG"`U7TBT7\BP"-
M!`(%H>O9;HE%^(-%_`3!3>@"BT7XB<+!RAN+1>@S1>0S1>R-!`*)P@-5\(M%
M_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%](G"P<H;BT7D,T7X,T7HC00"B<(#
M5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-^`*+1?")PL'*&XM%^#-%]#-%Y(T$
M`HG"`U7HBT7\BP"-!`(%H>O9;HE%[(-%_`3!3?0"BT7LB<+!RAN+1?0S1?`S
M1?B-!`*)P@-5Y(M%_(L`C00"!:'KV6Z)1>B#1?P$P4WP`HM%Z(G"P<H;BT7P
M,T7L,T7TC00"B<(#5?B+1?R+`(T$`@6AZ]ENB47D@T7\!,%-[`*+1>2)PL'*
M&XM%[#-%Z#-%\(T$`HG"`U7TBT7\BP"-!`(%H>O9;HE%^(-%_`3!3>@"BT7X
MB<+!RAN+1>@S1>0S1>R-!`*)P@-5\(M%_(L`C00"!:'KV6Z)1?2#1?P$P4WD
M`HM%](G"P<H;BT7D,T7X,T7HC00"B<(#5>R+1?R+`(T$`@6AZ]ENB47P@T7\
M!,%-^`*+1?")PL'*&XM%^#-%]#-%Y(T$`HG"`U7HBT7\BP"-!`(%H>O9;HE%
M[(-%_`3!3?0"BT7LB<+!RAN+1?0S1?`S1?B-!`*)P@-5Y(M%_(L`C00"!:'K
MV6Z)1>B#1?P$P4WP`HM%Z(G"P<H;BT7P,T7L,T7TC00"B<(#5?B+1?R+`(T$
M`@6AZ]ENB47D@T7\!,%-[`*+1>2)PL'*&XM%[#-%Z#-%\(T$`HG"`U7TBT7\
MBP"-!`(%H>O9;HE%^(-%_`3!3>@"BT7XB<+!RAN+1>@S1>0S1>R-!`*)P@-5
M\(M%_(L`C00"!:'KV6Z)1?2#1?P$P4WD`HM%](G"P<H;BT7D,T7X,T7HC00"
MB<(#5>R+1?R+`(T$`@6AZ]ENB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"
M(U7TBT7D(T7X"="-!`&)P@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%
M[(G!P<D;BT7X"T7TB<(C5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D
M<(E%Z(-%_`3!3?`"BT7HB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#
M5?B+1?R+`(T$`BTD0^1PB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7H
MBT7P(T7L"="-!`&)P@-5](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!
MP<D;BT7L"T7HB<(C5>2+1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%
M](-%_`3!3>0"BT7TB<'!R1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+
M1?R+`(T$`BTD0^1PB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D
M(T7X"="-!`&)P@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;
MBT7X"T7TB<(C5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%
M_`3!3?`"BT7HB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#5?B+1?R+
M`(T$`BTD0^1PB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7HBT7P(T7L
M"="-!`&)P@-5](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!P<D;BT7L
M"T7HB<(C5>2+1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%](-%_`3!
M3>0"BT7TB<'!R1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+1?R+`(T$
M`BTD0^1PB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D(T7X"="-
M!`&)P@-5Z(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;BT7X"T7T
MB<(C5?"+1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%_`3!3?`"
MBT7HB<'!R1N+1?0+1?")PB-5[(M%]"-%\`G0C00!B<(#5?B+1?R+`(T$`BTD
M0^1PB47D@T7\!,%-[`*+1>2)P<')&XM%\`M%[(G"(U7HBT7P(T7L"="-!`&)
MP@-5](M%_(L`C00"+21#Y'")1?B#1?P$P4WH`HM%^(G!P<D;BT7L"T7HB<(C
M5>2+1>PC1>@)T(T$`8G"`U7PBT7\BP"-!`(M)$/D<(E%](-%_`3!3>0"BT7T
MB<'!R1N+1>@+1>2)PB-5^(M%Z"-%Y`G0C00!B<(#5>R+1?R+`(T$`BTD0^1P
MB47P@T7\!,%-^`*+1?")P<')&XM%Y`M%^(G"(U7TBT7D(T7X"="-!`&)P@-5
MZ(M%_(L`C00"+21#Y'")1>R#1?P$P4WT`HM%[(G!P<D;BT7X"T7TB<(C5?"+
M1?@C1?0)T(T$`8G"`U7DBT7\BP"-!`(M)$/D<(E%Z(-%_`3!3?`"BT7HB<+!
MRAN+1?`S1>PS1?2-!`*)P@-5^(M%_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%
MY(G"P<H;BT7L,T7H,T7PC00"B<(#5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-
MZ`*+1?B)PL'*&XM%Z#-%Y#-%[(T$`HG"`U7PBT7\BP"-!`(M*CZ=-8E%](-%
M_`3!3>0"BT7TB<+!RAN+1>0S1?@S1>B-!`*)P@-5[(M%_(L`C00"+2H^G36)
M1?"#1?P$P4WX`HM%\(G"P<H;BT7X,T7T,T7DC00"B<(#5>B+1?R+`(T$`BTJ
M/ITUB47L@T7\!,%-]`*+1>R)PL'*&XM%]#-%\#-%^(T$`HG"`U7DBT7\BP"-
M!`(M*CZ=-8E%Z(-%_`3!3?`"BT7HB<+!RAN+1?`S1>PS1?2-!`*)P@-5^(M%
M_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%Y(G"P<H;BT7L,T7H,T7PC00"B<(#
M5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-Z`*+1?B)PL'*&XM%Z#-%Y#-%[(T$
M`HG"`U7PBT7\BP"-!`(M*CZ=-8E%](-%_`3!3>0"BT7TB<+!RAN+1>0S1?@S
M1>B-!`*)P@-5[(M%_(L`C00"+2H^G36)1?"#1?P$P4WX`HM%\(G"P<H;BT7X
M,T7T,T7DC00"B<(#5>B+1?R+`(T$`BTJ/ITUB47L@T7\!,%-]`*+1>R)PL'*
M&XM%]#-%\#-%^(T$`HG"`U7DBT7\BP"-!`(M*CZ=-8E%Z(-%_`3!3?`"BT7H
MB<+!RAN+1?`S1>PS1?2-!`*)P@-5^(M%_(L`C00"+2H^G36)1>2#1?P$P4WL
M`HM%Y(G"P<H;BT7L,T7H,T7PC00"B<(#5?2+1?R+`(T$`BTJ/ITUB47X@T7\
M!,%-Z`*+1?B)PL'*&XM%Z#-%Y#-%[(T$`HG"`U7PBT7\BP"-!`(M*CZ=-8E%
M](-%_`3!3>0"BT7TB<+!RAN+1>0S1?@S1>B-!`*)P@-5[(M%_(L`C00"+2H^
MG36)1?"#1?P$P4WX`HM%\(G"P<H;BT7X,T7T,T7DC00"B<(#5>B+1?R+`(T$
M`BTJ/ITUB47L@T7\!,%-]`*+1>R)PL'*&XM%]#-%\#-%^(T$`HG"`U7DBT7\
MBP"-!`(M*CZ=-8E%Z(-%_`3!3?`"BT7HB<+!RAN+1?`S1>PS1?2-!`*)P@-5
M^(M%_(L`C00"+2H^G36)1>2#1?P$P4WL`HM%Y(G"P<H;BT7L,T7H,T7PC00"
MB<(#5?2+1?R+`(T$`BTJ/ITUB47X@T7\!,%-Z`*+10B+`(G"`U7XBT4(B1"+
M10B+0`2)P@-5Y(M%"(E0!(M%"(M`"(G"`U7HBT4(B5`(BT4(BT`,B<(#5>R+
M10B)4`R+10B+0!")P@-5\(M%"(E0$,G#58GEBT4(QP`!(T5GBT4(QT`$B:O-
M[XM%",=`"/[<NIB+10C'0`QV5#(0BT4(QT`0\.'2PXM%",=`%`````"+10C'
M0!@`````BT4(QT!<`````%W#58GE5U:#[!2+10B+4!2+11#!X`.-!`*)1?2+
M10B+0!0[1?1V#XM%"(M`&(U0`8M%"(E0&(M5"(M%](E"%(M%"(M0&(M%$,'H
M'0'"BT4(B5`8BT4(BT!<A<`/A.T```"+10B+4%RX0````"G0B47PBT7P.T40
M?@:+11")1?"+3?"+50B#PAR+10B+0%R-!`*+50R)QXG6_/.DBT7P*440BT7P
M`44,BT4(BT!<B<(#5?"+10B)4%R+10B+0%R#^$`/A:D```"+10B)!"3HJ.S_
M_^MZBT4(@\`<BU4,BPJ)"(M*!(E(!(M*"(E("(M*#(E(#(M*$(E($(M*%(E(
M%(M*&(E(&(M*'(E('(M*((E(((M*)(E()(M**(E(*(M*+(E(+(M*,(E(,(M*
M-(E(-(M*.(E(.(M2/(E0/(-%#$"#;1!`BT4(B00DZ"SL__^#?1`_?X"+31"+
M10B#P!R+50R)QXG6_/.DBU4(BT40B4)<@\047E]=PU6)Y8/L!(M%#(D$).CR
MZ___BT4,BP#!Z!B)PHM%"(@0BU4(@\(!BT4,BP#!Z!"(`HM5"(/"`HM%#(L`
MP>@(B`*+50B#P@.+10R+`(@"BU4(@\($BT4,BT`$P>@8B`*+50B#P@6+10R+
M0`3!Z!"(`HM5"(/"!HM%#(M`!,'H"(@"BU4(@\('BT4,BT`$B`*+50B#P@B+
M10R+0`C!Z!B(`HM5"(/""8M%#(M`",'H$(@"BU4(@\(*BT4,BT`(P>@(B`*+
M50B#P@N+10R+0`B(`HM5"(/"#(M%#(M`#,'H&(@"BU4(@\(-BT4,BT`,P>@0
MB`*+50B#P@Z+10R+0`S!Z`B(`HM5"(/"#XM%#(M`#(@"BU4(@\(0BT4,BT`0
MP>@8B`*+50B#PA&+10R+0!#!Z!"(`HM5"(/"$HM%#(M`$,'H"(@"BU4(@\(3
MBT4,BT`0B`+)PU6)Y5>#[!B+10R+0!2)1?2+10R+0!B)1?B+1?3!Z`.#X#^)
M1?"+50R#PAR+1?"-!`+&`("#1?`!@WWP.'Y&N$`````K1?")P8M5#(/"'(M%
M\(T$`HG'_+@`````\ZJ+10R)!"3H1^K__XM%#(/`'(G'_+H`````N`X```")
MP8G0\ZOK(+@X````*T7PB<&+50R#PAR+1?"-!`*)Q_RX`````/.JBT7XP>@8
MB<*+10R(4%2+1?C!Z!")PHM%#(A058M%^,'H"(G"BT4,B%!6BT7XB<*+10R(
M4%>+1?3!Z!B)PHM%#(A06(M%],'H$(G"BT4,B%!9BT7TP>@(B<*+10R(4%J+
M1?2)PHM%#(A06XM%#(E$)`2+10B)!"3HC?W__X/$&%]=PU6)Y5>#[%3'1>P`
M````QT7P`````,=%U)[9!`C'1=BNV00(QT7<MMD$",=%X,/9!`C'1>3(V00(
MQT7HVMD$",=%^`````#'1?0`````Z?P```"+1>R)!"3HIM___XE%\(-]\`!T
M"HM%\`^V`(3`=1>+10B)1"0$BT7LB00DZ)O?___IPP```(M%"(E$)`2+1?")
M!"3HU]O__X7`#X6I````BT4(N?____^)1<BX`````/R+?<CRKHG(]]"-4/^A
M_#X%"+G_____B47$N`````#\BWW$\JZ)R/?0@^@!`<*+1?"Y_____XE%P+@`
M````_(M]P/*NB<CWT(/H`8T$`H/``HD$).AVV___B47XBQ7\/@4(BT7PB40D
M$(E4)`R+10B)1"0(QT0D!,G8!`B+1?B)!"3H:-C__XM%^(E$)`2+1>R)!"3H
MT][__X-%]`&+1?2+1(74B47LBT7L#[8`A,`/A>S^__^#Q%1?7<-5B>57@>RD
M@0``QT7,`````,=%T`````#'1=0`````QT6TV]D$",=%N./9!`C'1;S'V`0(
MQT7`VMD$",=%G$'9!`C'1:#HV00(QT6D[]D$",=%J/?9!`C'1:S\V00(QT6P
MVMD$",=%D`#:!`C'190%V@0(QT68VMD$",=%V`[:!`C'1=S:V00(QT7@````
M`,=%Y`````#'1>@`````QT7X`````,<$)+'8!`CHY]W__XE%U(-]U`!T*XM%
MU`^V`(3`="&+1=2)!"3HQOW__XM%U(D$).@+V___B86(?O__Z9$%``#'1<0`
M````ZR:+1=")!"3HG]W__XE%U(-]U`!T#HM%U(D$).C8VO__B47D@T7$`8-]
MY`!U%(M%Q(M$A9")1="+1=`/M@"$P'7`@WWD`'4)QT7D$]H$".L^BT7DB47(
MZRSHZ]C__XL0BT7(#[8`#[[``<"-!`(/MP`/M\"#X`B%P'4&BT7(Q@!?@T7(
M`8M%R`^V`(3`=<K'1<0`````ZWJ+1=")!"3H"=W__XE%U(-]U`!T8HV%D'[_
M_XE$)`2+1=2)!"3HB!@``(7`=4F+A:!^__\E`/```#T`0```=!*+A:!^__\E
M`/```#T`H```=27'1"0$`@```(M%U(D$).@=V/__A<!U#HM%U(D$).CNV?__
MB47,@T7$`8-]S`!U&(M%Q(M$A9R)1="+1=`/M@"$P`^%:/___\=%Q`````#K
M9HV%D'[__XE$)`2+1=2)!"3H^Q<``(7`=4F+A:!^__\E`/```#T`0```=!*+
MA:!^__\E`/```#T`H```=27'1"0$`@```(M%U(D$).B0U___A<!U#HM%U(D$
M).AAV?__B47,@T7$`8-]S`!U%(M%Q(M$A;2)1=2+1=0/M@"$P'6`BT7,N?__
M__^)A81^__^X`````/R+O81^___RKHG(]]"-4/^+1=BY_____XF%@'[__[@`
M````_(N]@'[___*NB<CWT(/H`0'"BT7DN?____^)A7Q^__^X`````/R+O7Q^
M___RKHG(]]"#Z`$!PHM%W+G_____B85X?O__N`````#\B[UX?O__\JZ)R/?0
M@^@!C00"!0`$``")1?B+1?B)!"3HRM?__XE%Z(L5^#X%"(M%Y(E$)!2+1=B)
M1"00B50D#(M%S(E$)`C'1"0$&MH$"(M%Z(D$).BUU/__QT0D!.T!``"+1>B)
M!"3HTM3__\<$),/9!`CH^=K__XE%U(M%U(D$).@XV/__B<*+10B+`(E4)`2)
M!"3H@][__XE%X(-]X`!U"(M%"(L`B47@Z/'C__^%P`^%)P(``,=$)`0`````
MBT7@B00DZ+34__^)1>R#?>P`#X0'`@``QT0D#`(```#'1"0$[O___\=$)`C_
M____BT7LB00DZ-37___'1"0(!@```(V%!'___XE$)`2+1>R)!"3H9]7__P^V
MA01___^$P`^%P0````^VA05___\\0P^%L@````^VA09___\\00^%HP````^V
MA0=___\\0P^%E`````^VA0A___\\2`^%A0````^VA0E___\\175ZQT0D#`(`
M``#'1"0$QO___\=$)`C_____BT7LB00DZ#[7___'1"0(*0```(V%!'___XE$
M)`2+1>R)!"3HT=3__XL5^#X%"(M%W(E$)!2-A01___^)1"00B50D#(M%Z(E$
M)`C'1"0$(]H$"(M%Z(D$).@LT___Z4$!``"-A03___^)!"3H-_7__^L?BT7P
MB40D"(V%!'___XE$)`2-A03___^)!"3H:O7__\=$)`@`@```C84$?___B40D
M!(M%[(D$).A+U/__B47P@WWP`'^[BT7LB00DZ'?5__^-A03___^)1"0$C87P
M?O__B00DZ.GW___'1?0`````ZS6+1?0/MH0%\'[__P^VR(M%]`'`B<*-A6?_
M__\!T(E,)`C'1"0$,MH$"(D$).AUTO__@T7T`8-]]!-^Q<9%CP"+%?@^!0B+
M1=R)1"04C85G____B40D$(E4)`R+1>B)1"0(QT0D!"/:!`B+1>B)!"3H,M+_
M_^M*QT0D!'C9!`C'!"3LV`0(Z)G8___H-]+__XG"BPWX/@4(BT7<B40D%(E4
M)!")3"0,BT7HB40D",=$)`0WV@0(BT7HB00DZ.;1__^+1>B)1"0$QP0DL=@$
M".A0V/__BT7HB00DZ"CX__^+1>B)A8A^__^+A8A^__^!Q*2!``!?7<-5B>57
M@>R4````QT7T`````(M%"(D$).B$T___B47L@WWL``^$2P$``.D2`0``BT7P
M@\`3QT0D!,?8!`B)!"3H/-7__X7`#X3T````BT7P@\`3QT0D!$7:!`B)!"3H
M'M7__X7`#X36````BT4(N?____^)18BX`````/R+?8CRKHG(]]"-4/^+1?"#
MP!.Y_____XE%A+@`````_(M]A/*NB<CWT(/H`8T$`H/``HE%^(M%^(D$).C5
MT___B47TBT7P@\`3B40D#(M%"(E$)`C'1"0$2-H$"(M%](D$).C.T/__C46,
MB40D!(M%](D$).B,$@``@_C_="J+19PE`/```#T`0```=1N#?0P`=!7'1"0$
M`0```(M%](D$).C?_O__ZPN+1?2)!"3HTM+__XM%](D$).@7TO__QT7T````
M`(M%[(D$).B5TO__B47P@WWP``^%UO[__XM%[(D$).CMTO__@WT(`'0+BT4(
MB00DZ#S3__^!Q)0```!?7<-5B>6#[!B+10B)!"3HNMS__XE%^(M%^(D$).AJ
MW/__B47\Z)[?__^%P'1.@WT(`'1(BT4(#[8`A,!T/L=$)`0.V@0(BT7\B00D
MZ+72__\[1?QU)L=$)`0!````BT4(B00DZ!W^___'1"0$`````(M%^(D$).@*
M_O__R<-5B>53@^P4H4`_!0B+4`2A*#\%"(E"(*%`/P4(BU`$H30_!0@/MT`0
M#[?`B4(DH4`_!0B+6`3'1"0$`````,<$)-K9!`CHSM+__XE#**%`/P4(BU`$
MH3@_!0B)0BRA0#\%"(M0!*$@/P4(B4(PH4`_!0B+0`3'0#0`````@\046UW#
M58GE@^P(QP0D_____^C4T/__QT0D!`````#'!"0HQ@0(Z"#3___)PU6)Y8/L
M2,=%]`````#&!3P_!0@!QP0DT-@$".A1U?__B47X@WWX`'07BT7X#[8`/#%U
M#8M%^(/``0^V`(3`=`7HIMS__\=$)`@*````QT0D!`$```#'!"1.V@0(Z+W/
M__^)1>2#?>0`#X3I````BT7DBP"+0""+0!")1>C'1?`!````Z9(```"+1?"#
MZ`''1"0(`````(E$)`2+1>B)!"3H^=#__XE%[(-][`!T>HM%[(L`BT`()0``
M!`"%P'0.BT7LBP"+`(L`B470ZR"+1>R+`,=$)`@"````QT0D!`````")!"3H
M1-+__XE%T(M%\,'@`HG"H:Q/!0B-!`*+`(M5T(E4)`2)!"3HT-'__X7`=1:#
M1?0!@T7P`:&H3P4(.47P#XQ@____H:A/!0B#Z`$[1?1U(L=%\`$```#K#XM%
MZ(D$).C%SO__@T7P`:&H3P4(.47P?.?'1"0(!````,=$)`0!````QP0D4]H$
M".BKSO__B47D@WWD`'1"BT7DBP"+0""+`,=$)`15V@0(B00DZ+C.__^+1>2+
M`(M`((L`BT`()0!```"%P'02BT7DBP"+0""+`(D$).A`T/__QT0D"`0```#'
M1"0$`0```,<$)%K:!`CH1,[__XE%Y(-]Y`!T5,=%_`````#'!"2ZV`0(Z'O3
M__^)1?R#??P`=!N+1>2+`(M`((L0BT7\B40D!(D4).@VSO__ZQVAK$\%"(L0
MBT7DBP"+0""+`(E4)`2)!"3HU='__\8%/#\%"`#'!3`_!0@`````QP0DL=@$
M".@=T___HZ1/!0BAI$\%"(7`#X7P````H:Q/!0B)!"3H9_3__Z.D3P4(H:Q/
M!0B)1=2+1>2+`(M`((L`BT`()0``!`"%P'03BT7DBP"+0""+`(L`BP")1=CK
M)8M%Y(L`BT`@BP#'1"0(`@```,=$)`0`````B00DZ&/0__^)1=B+5=2)5"0$
MBT78B00DZ&[.__^)1?"+1>2+`(M`((L`BT`()0``!`"%P'03BT7DBP"+0""+
M`(L`BP")1=SK)8M%Y(L`BT`@BP#'1"0(`@```,=$)`0`````B00DZ`#0__^)
M1=RAK$\%"(L0BT7PB40D#(M%W(E$)`B)5"0$QP0D7-H$".A(S___H:1/!0C'
M1"0$[0$``(D$).C3R___B47P@WWP`'0T@WWP$70N@WWP_W0HBQ6D3P4(H:Q/
M!0B+"(M%\(E$)`R)5"0(B4PD!,<$)(S:!`CH]L[__\G#58GE@^P8Z"W0___'
M1"0(VMD$",=$)`32Q@0(QP0DVMH$".C=SO__QT0D!-K9!`B)!"3H;<S__\G#
MC4PD!(/D\/]Q_%6)Y5&#[#2)3>C'1"0$`0```,<$)`@```#H@\O__Z-(/P4(
M#[8%3#\%"(3`=3;H;LS__Z.@3P4(H:!/!0B%P'4,QP0D`0```.BTSO__H:!/
M!0B)!"3HY\S__\<%)#\%"``````/M@4L/P4(@\@"HBP_!0@/M@4L/P4(@\@!
MHBP_!0B+5>B+`H/`!3W___\_=@S'!"10/P4(Z!3.__^+3>B+`<'@`H/`%(D$
M).C!S?__HZQ/!0B+%:Q/!0B+3>B+002+`(D"H:Q/!0B#P`3'`._:!`BAK$\%
M"(/`",<`(-L$",<%J$\%"`,```"AJ$\%",'@`HG"H:Q/!0B-!`+'`/+:!`BA
MJ$\%"(/``:.H3P4(QT7X`0```.LLH:A/!0@#1?C!X`*)PJ&L3P4(C00"C5#\
MBT7XP>`"BTWH`T$$BP")`H-%^`&+1?B+5>@[`GS*H:A/!0B+3>@#`<'@`HG"
MH:Q/!0B-!`*#Z`3'``````"+#:Q/!0BAJ$\%"(M5Z`,"@^@!BQ6@3P4(QT0D
M$`````")3"0,B40D",=$)`1\R@0(B10DZ-G)__^)1?2#??0`=1"AH$\%"(D$
M).A3RO__B47TH:!/!0B)!"3H$\S__\<$).#8!`CHJL___X7`=3"AI$\%"(7`
M=1''!"2QV`0(Z)'/__^CI$\%"*&D3P4(A<!T#:&D3P4(B00DZ.#X__^AH$\%
M"(D$).A&R?__BT7T@\0T65V-8?S#D)"0D)"0D)"0D(/L'(E<)!#H0`H``('#
MV'```(E\)!B)="04BXOD____B[O8____BP&+%XLP@^@$B0&+@_S___^+"(T$
ML2G"P>H"=16-!+&)!XM<)!"+="04BWPD&(/$',.-@_SJ__^)!"3H&LS__XUV
M`(V\)P````!55U93Z-,)``"!PVMP``"#[#R+D^3___^+@]C___^+,(L"BRB#
MZ`2)`HN3_/___XT,K00```"+.HE,)#B+!`_V0`H$#X0)`@``BP"+`(E$)#2-
M!*\IQL'^`H/N`0^.'@(``(NS_/___XM4)#B+!HML`@3'1"0P`````(7M=$:+
M10B-DT[L__^)5"0LJ0``#P</A&H!``"I```$``^$?P(``(M%`(L`C8M.[/__
MB<>)3"0LBW0D++D%````_/.F#X4\`0``BX/4____C;-L[/__B70D"(E$)`2-
M@WGL__^)!"3H.LO__XN#W/___XET)`B)1"0$C8.2[/__B00DZ![+__^+@^S_
M__^)="0(B40D!(V#K>S__XD$).@"R___BX/X____B70D"(E$)`2-@\CL__^)
M!"3HYLK__XN#]/___XET)`B)1"0$C8/E[/__B00DZ,K*__^+@_#___^)="0(
MB40D!(V#`>W__XD$).BNRO__C8-4[/__QT0D!`````")!"3HZ,K__\>#X!$`
M``````")@]P1``"-@Q;M__^)!"3HFL?__X7`=";'1"0,`````,=$)`@*````
MQT0D!`````")!"3HYL?__XF#X!$``(N+_/___XN#Z/___XMT)#B+$8D$%HL!
MBY/8____`<:),H/$/%M>7UW#C;0F`````(M$)#"%P`^$]````(M$)#2-DU/L
M__^-BU7L__^)1"00BT0D+(MT)#")5"0,BU0D-(EL)!R)1"0(C8,DZ___B70D
M&(E,)!2)5"0$B00DZ+[)___'1"0((@```,=$)`0`````B00DZ#;*__^)1"0T
MC02O*<;!_@*#[@$/C^/]__^0BTPD-(VS/.S__XV[1^S__XET)`B)/"2)3"0$
MZ$#'___'1"0$`````(D$).@@QO__A<")Q702BT`(B70D,*D```\'#X7._?__
MBT0D-(VS/^S__XET)`B)/"2)1"0$Z/[&___'1"0$`````(D$).C>Q?__B70D
M,(G%Z7W]__^-=@"-DU3L__^-LUCL__^)T8G0B70D,.D#____C;0F`````,=$
M)`@B````QT0D!`````")+"3H:,G__^EI_?__C78`@^P<B5PD#.B0!@``@<,H
M;0``B70D$(E\)!2);"08BXOD____BX/8____BQ"+`8LP@^@$B0&+B_S___^-
M!+4``````P$IPL'J`@^%B@```(N#X/___XL`]D`5('1SBY/0____BT`,BQ*+
M/(*+@]P1``"-;@&--*T`````BP"+`(D\)(E$)`3H]<7__XN#_/___XL`B40D
M"/9'"4!T"(D\).B+Q___BTPD"(N#_/___XD\J8N+V/___P,PB3&+7"0,BW0D
M$(M\)!2+;"08@\0<P^CKQO__B<?KDHV#)NW__XD$).CIQ___B?:-O"<`````
M@^PLB5PD'.B@!0``@<,X;```B6PD*(ET)"")?"0DBY/D____BX/8____BZO\
M____BS"+`HL(@^@$B0*+50"-!(HIQL'^`HU&_H/X`0^'[````(T\C00```"+
M!#KV0`H$#X2:````BP"+`(E$)!B+10"+1`<$]D`*`71WBP"+0`R)1"04@_X"
MC8-$[?__?A6+10"+1`<(]D`*!`^$@0```(L`BP")_@-U`(E$)`B+1"04B40D
M!(M$)!B)!"3H+\?__XD$).B'Q___B00DZ)_$__^)!HN#V/___P-]`(DXBUPD
M'(MT)""+?"0DBVPD*(/$+,.)!"3H9L7__XE$)!3KA,=$)`@"````QT0D!```
M``")!"3H6,?__XE$)!CI3?___\=$)`@"````QT0D!`````")!"3H-\?__^EF
M____C8-4Z___B00DZ)3&__^-="8`4X/L*.A3!```@</K:@``C40D-(E$)"2-
M1"0DB40D!(M$)#")!"3H9<3___9`"@2)PG0SBP"+0`2)1"0@BP*+$(M$)"")
M5"0$@\`!B40D((E$)`B+@]P1``")!"3H_\3__X/$*%O#C40D((D4),=$)`@"
M````B40D!.BBQO__B<+KOHVT)@````"-O"<`````@^P<B5PD#.C``P``@<-8
M:@``B70D$(E\)!2);"08BXOD____BX/8____BQ"+`8LP@^@$B0&+@_S___^+
M"(T$L2G"P?H"@_H"#X7+````C3RU!````(L$.?9`"@%T>8L`BW`,BY/\____
MBP*+1`<$]D`*!'1NBP"+`(DT)(G^B40D!.C)P___B<6+@_S___\#,.A:Q/__
MA>V)!G1DBY/\____B6PD!(L"BP0'B00DZ,W!__^+@_S___^+D]C___\#.(DZ
MBUPD#(MT)!"+?"04BVPD&(/$',.)!"3HH</__XG&ZX#'1"0(`@```,=$)`0`
M````B00DZ)7%___I>?___^A[Q/__B40D!(V#2^S__XD$).A9_O__ZYJ-@Z#K
M__^)!"3HV<3__XGVC;PG`````(/L'(E<)`SHD`(``('#*&D``(ET)!")?"04
MB6PD&(N+Y/___XN#V/___XL0BP&+,(/H!(D!BX/\____BPB-!+$IPL'Z`H/J
M`0^%X0```(TLM00```"+!"GV0`H!#X2^````BP"+>`R+@^#___^+`/9`%2`/
MA)<```"+D]#___^+0`R+$HLT@HD\).B1P?__A<`/E,`/MOB%_W15BX/\____
MBP")?"0$B30DB40D".B=P/__]D8)0'0(B30DZ&_#__^+1"0(B70%`(N#_/__
M_P,HBX/8____B2B+7"0,BW0D$(M\)!2+;"08@\0<PXUV`.A;P___B40D!(V#
M2^S__XD$).@Y_?__ZY*-M"8`````Z*O"__^)QNEK____C70F`(D$).@HPO__
MB<?I./___XV#W.O__XD$).B3P___C78`@^P<B5PD#.A0`0``@</H9P``B70D
M$(E\)!2);"08BY/D____BX/8____BS"+`HL(@^@$B0*+@_S___^+$(T$BBG&
MP?X"C4;_@_@!#X?]````C3R-!````(L$.O9`"@0/A*````"+`(LH,<"#[@%^
M'HN3_/___XL"BT0'!/9`"@$/A)X```"+`(M`#(/@`8.[X!$```$9TH/"`H7`
M=6*)5"0$B?Z)+"3HQ,'__XG%BX/\____`S#HQ<'__X7MB09T=(N3_/___XEL
M)`2+`HL$!XD$).@XO___BX/\____BY/8____`SB).HM<)`R+="00BWPD%(ML
M)!B#Q!S#C70F`(#.`>N9QT0D"`(```#'1"0$`````(D$).@#P___B<7I1?__
M_XD$).CDP/__@^`!D.E9____Z-;!__^)1"0$C8-+[/__B00DZ+3[___KBHV#
M".S__XD$).@TPO__BQPDPU6)Y5W#C70F`(V\)P````!5B>575E.#[`SH````
M`%N!PW9F``#H3K[__XV#N/[__XV3N/[__RG0P?@"B47P=!\Q_XG6BTT04(M5
M#(M%"%%'4E#_%H/&!(/$$#E]\'7EC67T6UY?7<.0D)"0D)"0D)!5B>53Z```
M``!;@<,;9@``BU4,BT4(4E!J`^C!OO__BUW\R<.0D)"0D)"0D)"0D)!5B>53
MZ`````!;@</K90``BU4,BT4(4E!J`^BAO___BUW\R<.0D)"0D)"0D)"0D)!5
MB>53NXP\!0B#[`2AC#P%"(/X_W0,@^L$_]"+`X/X_W7T@\0$6UW#58GE4X/L
M!.@`````6X'#D&4``.@0PO__65O)PP````````````````,````!``(`<&5R
M;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@`O<')O8R]S96QF
M+V5X90`O`#H`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-
M10`N`"5S)7,E<P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```$Q$7TQ)0E)!
M4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`!0051(`$193$1?3$E"4D%2
M65]0051(``!#.EQ414U0`"]T;7``5$U01$E2`%1%35!$25(`5$5-4`!435``
M55-%4@!54T523D%-10!P87(M`%-94U1%30`E<R5S)7,E<P`E<R5S8V%C:&4M
M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`
M,``E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``M90`M+0```````````````'!A<BYP;```````````
M````````````````````````(R$O=7-R+V)I;B]P97)L"@IE=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P
M;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE
M<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U
M.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@('5N;&EN:R!`=&UP9FEL93L*
M("`@(')M9&ER("1P87)?=&5M<#L*("`@("1P87)?=&5M<"`]?B!S>UM>7%PO
M72I;7%PO73\D?7M].PH@("`@<FUD:7(@)'!A<E]T96UP.PI]('T*"D)%1TE.
M('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV
M*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6
M>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*
M("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@
M?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R
M;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@
M("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C
M:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T
M('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L
M("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY
M("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*
M("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE
M(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C
M:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@
M7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[
M4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@
M("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C
M<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE
M+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS
M=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@
M("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@
M("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O
M<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@
M;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@
M("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@
M("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D
M9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`]
M(%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69]
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD[
M"@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C
M(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@
M;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET
M:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F
M('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@)&9I;&5N86UE('5N;&5S<R`D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO.PH@("`@("`@(&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P
M<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R
M(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@
M('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@
M("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@
M("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["B`@("!W:&EL92`H0$%21U8I
M('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@
M("`@("`@('5N<VAI9G0@0$E.0RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@
M("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@
M("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@
M("`@("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?
M;F%M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*
M("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN
M:71?:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@
M/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE
M9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@
M("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@
M("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*
M("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P
M.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F
M:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*
M"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N
M9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN
M8R@I.PH@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@
M*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN
M8R!]"@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T
M(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S
M<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H
M)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F
M:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@
M("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2
M(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A
M9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@
M>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@
M(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PH*("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"B`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>2!O<B`A)$5.
M5GM005)?5$5-4'T["B`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["B`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["B`@("`@("`@("`@(%X*("`@("`@("`@("`@+S]S:&QI8B\*("`@
M("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@
M("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@
M("`@("`@*%M>+UTK*0H@("`@("`@("`@("`D"B`@("`@("`@?7@["B`@("`@
M("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@(&UY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["B`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@?0H@("`@(R!]
M?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S
M:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T
M95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*"49I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN
M84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R
M:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*
M("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP
M.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E
M<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE
M.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@
M4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z
M.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PI]"@HC(%1H92!#('9E
M<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N
M8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?
M=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H
M(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@
M0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@
M)'5S97)N86UE(#T@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D*("`@("`@
M("`@("`@/R`F5VEN,S(Z.DQO9VEN3F%M92@I"B`@("`@("`@("`@(#H@)$5.
M5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@
M("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@
M("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X
M+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@
M("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@
M(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD
M(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@
M("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*
M"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@
M("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@
M*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*
M("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE
M(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL
M96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P
M96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@7W-E
M=%]P<F]G;F%M92!["B`@("!I9B`H)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@
M("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@
M("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@
M("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@
M("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*
M"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M
M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z("1%3E9[4%=$
M?3L*("`@("1P=V0@/2!@<'=D8"!I9B`A9&5F:6YE9"`D<'=D.PH@("`@8VAO
M;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?
M96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@
M('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*
M("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R
M971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R
M:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P
M<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T
M(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@
M=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE
M(#DR,`H*7U]%3D1?7PH``%5S86=E.B!$>6YA3&]A9&5R.CID;%]U;F1E9E]S
M>6UB;VQS*"D````E<R!O8FIE8W0@=F5R<VEO;B`E<R!D;V5S(&YO="!M871C
M:"`E<R5S)7,E<R`E7P!5<V%G93H@1'EN84QO861E<CHZ9&Q?:6YS=&%L;%]X
M<W5B*'!E<FQ?;F%M92P@<WEM<F5F+"!F:6QE;F%M93TB)%!A8VMA9V4B*0``
M57-A9V4Z($1Y;F%,;V%D97(Z.F1L7V9I;F1?<WEM8F]L*&QI8FAA;F1L92P@
M<WEM8F]L;F%M92D`````57-A9V4Z($1Y;F%,;V%D97(Z.F1L7W5N;&]A9%]F
M:6QE*&QI8G)E9BD```!5<V%G93H@1'EN84QO861E<CHZ9&Q?;&]A9%]F:6QE
M*&9I;&5N86UE+"!F;&%G<STP*0``6%-?5D524TE/3@`E<SHZ)7,`,2XP-0`D
M`#HZ`&)O;W1S=')A<"!P87)A;65T97(`1'EN84QO861E<BYC`$1Y;F%,;V%D
M97(Z.F1L7VQO861?9FEL90!$>6YA3&]A9&5R.CID;%]U;FQO861?9FEL90!$
M>6YA3&]A9&5R.CID;%]F:6YD7W-Y;6)O;`!$>6YA3&]A9&5R.CID;%]U;F1E
M9E]S>6UB;VQS`$1Y;F%,;V%D97(Z.F1L7VEN<W1A;&Q?>'-U8@!$>6YA3&]A
M9&5R.CID;%]E<G)O<@!015),7T1,7TY/3DQ!6ED`57-A9V4Z($1Y;F%,;V%D
M97(Z.F1L7V5R<F]R*"D`1'EN84QO861E<@```1L#.T@````(````S*'__V0`
M```\HO__@````'RE__^H````;*;__\@```"\I___Z````$RH__\$`0``?*G_
M_R0!``"\JO__1`$``!0``````````7I2``%\"`$;#`0$B`$``!@````<````
M8*'__V8`````0PX@1(,$4X8#AP(D````.````+2A__\]`P```$$."$$.#$$.
M$$$.%(,%A@2'`X4"3@Y0'````&````#,I/__YP````!##B!$@P57A0*'`X8$
M```<````@````)RE__],`0```$,.,$2#!5>'`X8$A0(``!@```"@````S*;_
M_X(`````00X(0PXP@P(````<````O````$"G__\G`0```$,.($2#!5>%`H<#
MA@0``!P```#<````4*C__ST!````0PX@1(,%5X4"AP.&!```'````/P```!P
MJ?__7`$```!##B!$@P57A0*'`X8$````````_____P````#_____````````
M```!`````0````$```"+`@```0```)<"```!````OP(```$```#)`@```0``
M`-<"```!````Y`(```\````D!```#````+B5!`@-````.-@$"/7^_V]H@00(
M!0```/R*!`@&````'(,$"`H```!6!@``"P```!`````5``````````,```#4
M/04(`@```!@"```4````$0```!<```"@DP0($0```-"2!`@2````T````!,`
M```(````_O__;U"2!`C___]O`@```/#__V]2D00(````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````*`\!0@`
M`````````.:5!`CVE00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6
M!`B&E@0(EI8$"*:6!`BVE@0(QI8$"-:6!`CFE@0(]I8$"`:7!`@6EP0()I<$
M"#:7!`A&EP0(5I<$"&:7!`AVEP0(AI<$"):7!`BFEP0(MI<$",:7!`C6EP0(
MYI<$"/:7!`@&F`0(%I@$"":8!`@VF`0(1I@$"%:8!`AFF`0(=I@$"(:8!`B6
MF`0(II@$"+:8!`C&F`0(UI@$".:8!`CVF`0(!ID$"!:9!`@FF00(-ID$"$:9
M!`A6F00(9ID$"':9!`B&F00(EID$"*:9!`BVF00(QID$"-:9!`CFF00(]ID$
M"`::!`@``````````)@\!0B=V`0(G]@$"/____\`VP0(KDT```!'0T,Z("A'
M3E4I(#0N,2XR(#(P,#8Q,3$P("AP<F5R96QE87-E*2`H-"XQ+C(M,"XR,#`V
M,3$Q,"XQ;61V,C`P-RXQ*0``1T-#.B`H1TY5*2`T+C$N,B`R,#`V,3$Q,"`H
M<')E<F5L96%S92D@*#0N,2XR+3`N,C`P-C$Q,3`N,6UD=C(P,#<N,2D``$=#
M0SH@*$=.52D@-"XQ+C(@,C`P-S`S,#(@*'!R97)E;&5A<V4I("@T+C$N,BTQ
M;61V,C`P-RXQ*0``1T-#.B`H1TY5*2`T+C$N,B`R,#`W,#,P,B`H<')E<F5L
M96%S92D@*#0N,2XR+3%M9'8R,#`W+C$I``!'0T,Z("A'3E4I(#0N,2XR(#(P
M,#<P,S`R("AP<F5R96QE87-E*2`H-"XQ+C(M,6UD=C(P,#<N,2D``$=#0SH@
M*$=.52D@-"XQ+C(@,C`P-S`Q,34@*'!R97)E;&5A<V4I("@T+C$N,BTP+C(P
M,#<P,3$U+C%M9'8R,#`W+C$I``!'0T,Z("A'3E4I(#0N,2XR(#(P,#<P,S`R
M("AP<F5R96QE87-E*2`H-"XQ+C(M,6UD=C(P,#<N,2D``$=#0SH@*$=.52D@
M-"XQ+C(@,C`P-C$Q,3`@*'!R97)E;&5A<V4I("@T+C$N,BTP+C(P,#8Q,3$P
M+C%M9'8R,#`W+C$I```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M````"P````$````"````-($$"#0!```3```````````````!`````````!,`
M```'`````@```$B!!`A(`0``(```````````````!``````````A````]O__
M;P(```!H@00(:`$``+0!```$``````````0````$````*P````L````"````
M'(,$"!P#``#@!P``!0````$````$````$````#,````#`````@```/R*!`C\
M"@``5@8``````````````0`````````[````____;P(```!2D00(4A$``/P`
M```$``````````(````"````2````/[__V\"````4)($"%`2``"`````!0``
M``(````$`````````%<````)`````@```-"2!`C0$@``T`````0`````````
M!`````@```!@````"0````(```"@DP0(H!,``!@"```$````"P````0````(
M````:0````$````&````N)4$"+@5```7```````````````$`````````&0`
M```!````!@```-"5!`C0%0``0`0`````````````!`````0```!O`````0``
M``8````0F@0($!H``"@^`````````````!``````````=0````$````&````
M.-@$"#A8```<```````````````$`````````'L````!`````@```&#8!`A@
M6```PU(`````````````(`````````"#`````0````(````D*P4()*L``$P`
M``````````````0`````````D0````$````"````<"L%"'"K```<`0``````
M```````$`````````)L````!`````P```(P\!0B,K```"```````````````
M!`````````"B`````0````,```"4/`4(E*P```@```````````````0`````
M````J0````$````#````G#P%")RL```$```````````````$`````````*X`
M```&`````P```*`\!0B@K`````$```4`````````!`````@```"W`````0``
M``,```"@/04(H*T``#0```````````````0````$````O`````$````#````
MU#T%"-2M```8`0`````````````$````!````,4````!`````P```.P^!0CL
MK@``(```````````````!`````````#+````"`````,````@/P4(#*\``)@0
M`````````````"``````````T`````$```````````````RO```$`@``````
M```````!``````````$````#```````````````0L0``V0``````````````
(`0``````````
